@@ -12,7 +12,6 @@ from mindflow.core.index import run_index
     help="Index path(s). You can pass as many folders/files/paths as you'd like. Pass `.` to reference all "
 )
 @click.argument("document_paths", type=str, nargs=-1, required=True)
-@click.option("--force", is_flag=True, default=False)
 @click.option("--refresh", is_flag=True, default=False)
-def index(document_paths: List[str], refresh: bool, force: bool) -> None:
-    run_index(document_paths, refresh, force)
+def index(document_paths: List[str], refresh: bool) -> None:
+    run_index(document_paths, refresh)
