@@ -1,7 +1,9 @@
 from mindflow.db.db.database import Collection
-from mindflow.db.objects.base import BaseObject, StaticObject
+from mindflow.db.objects.base import BaseObject
+from mindflow.db.objects.base import StaticObject
 from mindflow.db.objects.static_definition.service import ServiceID
 
+
 class Service(StaticObject):
     id: str
     name: str
@@ -10,8 +12,10 @@ class Service(StaticObject):
 
     _collection: Collection = Collection.SERVICE
 
+
 class ServiceConfig(BaseObject):
     """Service config object."""
+
     id: str
     api_key: str
     api_secret: str
@@ -35,15 +39,14 @@ class ConfiguredService:
         if service:
             for key, value in service.__dict__.items():
                 setattr(self, key, value)
-            
+
         if service_config:
             for key, value in service_config.__dict__.items():
                 if value not in [None, ""]:
                     setattr(self, key, value)
-        
-        
+
 
 class ConfiguredServices:
     @property
-    def openai(self) -> Service:
+    def openai(self) -> ConfiguredService:
         return ConfiguredService(ServiceID.OPENAI.value)
