@@ -1,8 +1,7 @@
 """
 Base Resolver Class
 """
-from typing import List
-from typing import Optional
+from typing import List, Dict
 
 from mindflow.db.objects.document import DocumentReference
 
@@ -12,12 +11,6 @@ class BaseResolver:
     Base class for resolvers
     """
 
-    @staticmethod
-    def read_document(document_path: str) -> Optional[str]:
-        """
-        Read a document.
-        """
-
     @staticmethod
     def should_resolve(document_path: str) -> bool:
         """
@@ -25,7 +18,7 @@ class BaseResolver:
         """
         return False
 
-    def resolve(self, document_path: str) -> List[DocumentReference]:
+    def resolve(self, document_path: str) -> List[Dict]:
         """
         Resolve a document path to text.
         """
